Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5914)

Unified Diff: chrome/browser/media/router/media_router.h

Issue 1228863005: [MediaRouter] The minimal change to make everything build on Android. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed test_support compile issue on ChromeOS Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/media/router/media_router.h
diff --git a/chrome/browser/media/router/media_router.h b/chrome/browser/media/router/media_router.h
index 1bd815c3e7e59d0b08a4218e221be593c6059f9e..3d9220b04608652ad31349c29ebd0aa21c7b74d7 100644
--- a/chrome/browser/media/router/media_router.h
+++ b/chrome/browser/media/router/media_router.h
@@ -13,6 +13,7 @@
#include "chrome/browser/media/router/media_route.h"
#include "chrome/browser/media/router/media_sink.h"
#include "chrome/browser/media/router/media_source.h"
+#include "components/keyed_service/core/keyed_service.h"
#include "content/public/browser/presentation_session_message.h"
namespace media_router {
@@ -36,14 +37,14 @@ const int kInvalidTabId = -1;
// An interface for handling resources related to media routing.
// Responsible for registering observers for receiving sink availability
// updates, handling route requests/responses, and operating on routes (e.g.
-// posting messages or closing).
-class MediaRouter {
+// posting messages or closing). Is a KeyedService.
imcheng 2015/07/16 18:28:19 This comment is redundant as the reader can easily
whywhat 2015/07/16 20:17:18 Done.
+class MediaRouter : public KeyedService {
public:
using PresentationSessionMessageCallback = base::Callback<void(
scoped_ptr<ScopedVector<content::PresentationSessionMessage>>)>;
using SendRouteMessageCallback = base::Callback<void(bool sent)>;
- virtual ~MediaRouter() {}
+ ~MediaRouter() override = default;
// Creates a media route from |source_id| to |sink_id|.
// |origin| is the URL of requestor's page.

Powered by Google App Engine
This is Rietveld 408576698